@@ -33,5 +33,7 @@
 
 extern void install_spine_signal_handler(void);
 extern void uninstall_spine_signal_handler(void);
+#ifdef HAVE_EXECINFO_H
 extern char ** backtrace_symbols();
 extern int backtrace();
+#endif
