@@ -189,7 +189,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 	session.retries     = set.snmp_retries;
 	session.timeout     = (snmp_timeout * 1000); /* net-snmp likes microseconds */
 
-	SPINE_LOG_MEDIUM(("Device[%i] INFO: SNMP Device '%s' has timeout %ld (%d), retries %d", host_id, hostname, session.timeout, snmp_timeout, session.retries));
+	SPINE_LOG_MEDIUM(("Device[%i] INFO: SNMP Device '%s' has a timeout of %ld (%d), with %d retries", host_id, hostnameport, session.timeout, snmp_timeout, session.retries));
 
 	if ((snmp_version == 2) || (snmp_version == 1)) {
 		session.community     = (unsigned char*) snmp_community;
@@ -224,7 +224,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 			session.securityAuthProto    = snmp_duplicate_objid(usmHMACSHA1AuthProtocol, USM_AUTH_PROTO_SHA_LEN);
 			session.securityAuthProtoLen = USM_AUTH_PROTO_SHA_LEN;
 		} else if (strcmp(snmp_auth_protocol, "SHA224") == 0) {
-			#if defined(HAVE_EVP_SHA224) && defined(usmHMAC128SHA224AuthProtocol)
+			#if defined(HAVE_EVP_SHA224) && defined(NETSNMP_USMAUTH_HMAC128SHA224)
 			session.securityAuthProto    = snmp_duplicate_objid(usmHMAC128SHA224AuthProtocol, OID_LENGTH(usmHMAC128SHA224AuthProtocol));
 			session.securityAuthProtoLen = OID_LENGTH(usmHMAC128SHA224AuthProtocol);
 			#else
@@ -232,8 +232,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 			return 0;
 			#endif
 		} else if (strcmp(snmp_auth_protocol, "SHA256") == 0) {
-			//#if defined(HAVE_EVP_SHA224) && defined(usmHMAC192SHA256AuthProtocol)
-			#if defined(HAVE_EVP_SHA224) && defined(usmHMAC192SHA256AuthProtocol)
+			#if defined(HAVE_EVP_SHA224) && defined(NETSNMP_USMAUTH_HMAC192SHA256)
 			session.securityAuthProto    = snmp_duplicate_objid(usmHMAC192SHA256AuthProtocol, OID_LENGTH(usmHMAC192SHA256AuthProtocol));
 			session.securityAuthProtoLen = OID_LENGTH(usmHMAC192SHA256AuthProtocol);
 			#else
@@ -241,7 +240,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 			return 0;
 			#endif
 		} else if (strcmp(snmp_auth_protocol, "SHA384") == 0) {
-			#if defined(HAVE_EVP_SHA384) && defined(usmHMAC256SHA384AuthProtocol)
+			#if defined(HAVE_EVP_SHA384) && defined(NETSNMP_USMAUTH_HMAC256SHA384)
 			session.securityAuthProto    = snmp_duplicate_objid(usmHMAC256SHA384AuthProtocol, OID_LENGTH(usmHMAC256SHA384AuthProtocol));
 			session.securityAuthProtoLen = USM_HMAC256SHA384_AUTH_LEN;
 			#else
@@ -249,7 +248,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 			return 0;
 			#endif
 		} else if (strcmp(snmp_auth_protocol, "SHA512") == 0) {
-			#if defined(HAVE_EVP_SHA384) && defined(usmHMAC384SHA512AuthProtocol)
+			#if defined(HAVE_EVP_SHA384) && defined(NETSNMP_USMAUTH_HMAC384SHA512)
 			session.securityAuthProto    = snmp_duplicate_objid(usmHMAC384SHA512AuthProtocol, OID_LENGTH(usmHMAC384SHA512AuthProtocol));
 			session.securityAuthProtoLen = USM_HMAC384SHA512_AUTH_LEN;
 			#else
@@ -284,7 +283,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 			}
 		} else {
 			if (strcmp(snmp_priv_protocol, "DES") == 0) {
-				#if defined(USM_PRIV_PROTO_DES_LEN) && !defined(NETSNMP_DISABLE_DES)
+				#if defined(USM_PRIV_PROTO_DES_LEN)
 				session.securityPrivProto    = snmp_duplicate_objid(usmDESPrivProtocol, USM_PRIV_PROTO_DES_LEN);
 				session.securityPrivProtoLen = USM_PRIV_PROTO_DES_LEN;
 				session.securityPrivKeyLen   = USM_PRIV_KU_LEN;
@@ -306,7 +305,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 				session.securityLevel        = SNMP_SEC_LEVEL_AUTHPRIV;
 				#endif
 			} else if(strcmp(snmp_priv_protocol, "AES192") == 0) {
-				#if defined(NETSNMP_DRAFT_BLUMENTHAL_AES_04) && defined(usmAES192PrivProtocol)
+				#if defined(NETSNMP_DRAFT_BLUMENTHAL_AES_04) && defined(USM_CREATE_USER_PRIV_AES192)
 				session.securityPrivProto    = snmp_duplicate_objid(usmAES192PrivProtocol, OID_LENGTH(usmAES192PrivProtocol));
 				session.securityPrivProtoLen = OID_LENGTH(usmAES192PrivProtocol);
 				session.securityPrivKeyLen   = BYTESIZE(SNMP_TRANS_PRIVLEN_AES192);
@@ -316,7 +315,7 @@ void *snmp_host_init(int host_id, char *hostname, int snmp_version, char *snmp_c
 				return 0;
 				#endif
 			} else if(strcmp(snmp_priv_protocol, "AES256") == 0) {
-				#if defined(NETSNMP_DRAFT_BLUMENTHAL_AES_04) && defined(usmAES256PrivProtocol)
+				#if defined(NETSNMP_DRAFT_BLUMENTHAL_AES_04) && defined(USM_CREATE_USER_PRIV_AES256)
 				session.securityPrivProto    = snmp_duplicate_objid(usmAES256PrivProtocol, OID_LENGTH(usmAES256PrivProtocol));
 				session.securityPrivProtoLen = OID_LENGTH(usmAES256PrivProtocol);
 				session.securityPrivKeyLen   = BYTESIZE(SNMP_TRANS_PRIVLEN_AES256);
@@ -369,7 +368,7 @@ void snmp_host_cleanup(void *snmp_session) {
 	}
 }
 
-/*! \fn char *snmp_get(host_t *current_host, char *snmp_oid)
+/*! \fn char *snmp_get_base(host_t *current_host, char *snmp_oid, bool should_fail)
  *  \brief performs a single snmp_get for a specific snmp OID
  *
  *	This function will poll a specific snmp OID for a host.  The host snmp
@@ -379,7 +378,7 @@ void snmp_host_cleanup(void *snmp_session) {
  *  unsuccessful.
  *
  */
-char *snmp_get(host_t *current_host, char *snmp_oid) {
+char *snmp_get_base(host_t *current_host, char *snmp_oid, bool should_fail) {
 	struct snmp_pdu *pdu       = NULL;
 	struct snmp_pdu *response  = NULL;
 	struct variable_list *vars = NULL;
@@ -457,7 +456,7 @@ char *snmp_get(host_t *current_host, char *snmp_oid) {
 		}
 	}
 
-	if (status != STAT_SUCCESS) {
+	if (status != STAT_SUCCESS && should_fail) {
 		current_host->ignore_host = TRUE;
 
 		SET_UNDEFINED(result_string);
@@ -466,6 +465,10 @@ char *snmp_get(host_t *current_host, char *snmp_oid) {
 	return result_string;
 }
 
+char *snmp_get(host_t *current_host, char *snmp_oid) {
+	return snmp_get_base(current_host, snmp_oid, true);
+}
+
 /*! \fn char *snmp_getnext(host_t *current_host, char *snmp_oid)
  *  \brief performs a single snmp_getnext for a specific snmp OID
  *
