@@ -136,9 +136,15 @@ int putsetting(MYSQL *psql, int mode, const char *mysetting, const char *myvalue
 	assert(mysetting != 0);
 	assert(myvalue   != 0);
 
-	sprintf(qstring, "INSERT INTO settings (name, value) "
-		"VALUES ('%s', '%s') "
-		"ON DUPLICATE KEY UPDATE value=VALUES(value)", mysetting, myvalue);
+	if (set.dbonupdate == 0) {
+		sprintf(qstring, "INSERT INTO settings (name, value) "
+			"VALUES ('%s', '%s') "
+			"ON DUPLICATE KEY UPDATE value = VALUES(value)", mysetting, myvalue);
+	} else {
+		sprintf(qstring, "INSERT INTO settings (name, value) "
+			"VALUES ('%s', '%s') AS rs "
+			"ON DUPLICATE KEY UPDATE value = rs.value", mysetting, myvalue);
+	}
 
 	result = db_insert(psql, mode, qstring);
 
@@ -349,12 +355,19 @@ void read_config_options() {
 	}
 
 	/* get the mysql server version */
-	set.dbversion = 0;
 	if ((res = getglobalvariable(&mysql, LOCAL, "version")) != 0) {
-		set.dbversion = atoi(res);
+		snprintf(set.dbversion, SMALL_BUFSIZE, "%s", res);
 		free((char *)res);
 	}
 
+	if (STRIMATCH(set.dbversion, "mariadb")) {
+		set.dbonupdate = 0;
+	} else if (strpos(set.dbversion, "8.") == 0) {
+		set.dbonupdate = 1;
+	} else {
+		set.dbonupdate = 0;
+	}
+
 	/* get logging level from database - overrides spine.conf */
 	if ((res = getsetting(&mysql, LOCAL, "log_verbosity")) != 0) {
 		const int n = atoi(res);
@@ -419,6 +432,9 @@ void read_config_options() {
 	/* log the path_cactilog variable */
 	SPINE_LOG_DEBUG(("DEBUG: The path_cactilog variable is %s", set.path_logfile));
 
+	/* the version variable */
+	SPINE_LOG_DEBUG(("DEBUG: The version variable is %s", set.dbversion));
+
 	/* log the log_destination variable */
 	SPINE_LOG_DEBUG(("DEBUG: The log_destination variable is %i (%s)",
 		set.log_destination,
@@ -621,7 +637,7 @@ void read_config_options() {
 	/* log the script timeout value */
 	SPINE_LOG_DEBUG(("DEBUG: The number of php script servers to run is %i", set.php_servers));
 
-	/* get the number of script server processes to run */
+	/* get the number of active profiles on the system run */
 	if ((res = getsetting(&mysql, LOCAL, "active_profiles")) != 0) {
 		set.active_profiles = atoi(res);
 		free((char *)res);
@@ -636,6 +652,21 @@ void read_config_options() {
 	/* log the script timeout value */
 	SPINE_LOG_DEBUG(("DEBUG: The number of active data source profiles is %i", set.active_profiles));
 
+	/* get the number of snmp_ports in use */
+	if ((res = getsetting(&mysql, LOCAL, "total_snmp_ports")) != 0) {
+		set.total_snmp_ports = atoi(res);
+		free((char *)res);
+
+		if (set.total_snmp_ports <= 0) {
+			set.total_snmp_ports = 0;
+		}
+	} else {
+		set.total_snmp_ports = 0;
+	}
+
+	/* log the script timeout value */
+	SPINE_LOG_DEBUG(("DEBUG: The number of snmp ports on the system is %i", set.total_snmp_ports));
+
 	/*----------------------------------------------------------------
 	 * determine if the php script server is required by searching for
 	 * all the host records for an action of POLLER_ACTION_PHP_SCRIPT_SERVER.
@@ -755,12 +786,13 @@ void poller_push_data_to_main() {
 	MYSQL_ROW  row;
 	int        num_rows;
 	int        rows;
-	char       sqlbuf[MEGA_BUFSIZE];
+	char       sqlbuf[HUGE_BUFSIZE];
 	char       *sqlp = sqlbuf;
 	char       query[MEGA_BUFSIZE];
 	char       prefix[BUFSIZE];
 	char       suffix[BUFSIZE];
-	char       tmpstr[SMALL_BUFSIZE];
+	// tmpstr needs to be greater than 2 * the maximum column size being processed below
+	char       tmpstr[DBL_BUFSIZE];
 
 	db_connect(LOCAL, &mysql);
 	db_connect(REMOTE, &mysqlr);
@@ -798,27 +830,51 @@ void poller_push_data_to_main() {
 		"status_last_error, min_time, max_time, cur_time, avg_time, polling_time, "
 		"total_polls, failed_polls, availability, last_updated) VALUES ");
 
-	snprintf(suffix, BUFSIZE, " ON DUPLICATE KEY UPDATE "
-		"snmp_sysDescr=VALUES(snmp_sysDescr), "
-		"snmp_sysObjectID=VALUES(snmp_sysObjectID), "
-        "snmp_sysUpTimeInstance=VALUES(snmp_sysUpTimeInstance), "
-		"snmp_sysContact=VALUES(snmp_sysContact), "
-		"snmp_sysName=VALUES(snmp_sysName), "
-		"snmp_sysLocation=VALUES(snmp_sysLocation), "
-        "status=VALUES(status), "
-		"status_event_count=VALUES(status_event_count), "
-		"status_fail_date=VALUES(status_fail_date), "
-		"status_rec_date=VALUES(status_rec_date), "
-        "status_last_error=VALUES(status_last_error), "
-		"min_time=VALUES(min_time), "
-		"max_time=VALUES(max_time), "
-		"cur_time=VALUES(cur_time), "
-		"avg_time=VALUES(avg_time), "
-		"polling_time=VALUES(polling_time), "
-        "total_polls=VALUES(total_polls), "
-		"failed_polls=VALUES(failed_polls), "
-		"availability=VALUES(availability), "
-		"last_updated=VALUES(last_updated);");
+	if (set.dbonupdate == 0) {
+		snprintf(suffix, BUFSIZE, " ON DUPLICATE KEY UPDATE "
+			"snmp_sysDescr=VALUES(snmp_sysDescr), "
+			"snmp_sysObjectID=VALUES(snmp_sysObjectID), "
+			"snmp_sysUpTimeInstance=VALUES(snmp_sysUpTimeInstance), "
+			"snmp_sysContact=VALUES(snmp_sysContact), "
+			"snmp_sysName=VALUES(snmp_sysName), "
+			"snmp_sysLocation=VALUES(snmp_sysLocation), "
+			"status=VALUES(status), "
+			"status_event_count=VALUES(status_event_count), "
+			"status_fail_date=VALUES(status_fail_date), "
+			"status_rec_date=VALUES(status_rec_date), "
+			"status_last_error=VALUES(status_last_error), "
+			"min_time=VALUES(min_time), "
+			"max_time=VALUES(max_time), "
+			"cur_time=VALUES(cur_time), "
+			"avg_time=VALUES(avg_time), "
+			"polling_time=VALUES(polling_time), "
+			"total_polls=VALUES(total_polls), "
+			"failed_polls=VALUES(failed_polls), "
+			"availability=VALUES(availability), "
+			"last_updated=VALUES(last_updated)");
+	} else {
+		snprintf(suffix, BUFSIZE, " AS rs ON DUPLICATE KEY UPDATE "
+			"snmp_sysDescr=rs.snmp_sysDescr, "
+			"snmp_sysObjectID=rs.snmp_sysObjectID, "
+			"snmp_sysUpTimeInstance=rs.snmp_sysUpTimeInstance, "
+			"snmp_sysContact=rs.snmp_sysContact, "
+			"snmp_sysName=rs.snmp_sysName, "
+			"snmp_sysLocation=rs.snmp_sysLocation, "
+			"status=rs.status, "
+			"status_event_count=rs.status_event_count, "
+			"status_fail_date=rs.status_fail_date, "
+			"status_rec_date=rs.status_rec_date, "
+			"status_last_error=rs.status_last_error, "
+			"min_time=rs.min_time, "
+			"max_time=rs.max_time, "
+			"cur_time=rs.cur_time, "
+			"avg_time=rs.avg_time, "
+			"polling_time=rs.polling_time, "
+			"total_polls=rs.total_polls, "
+			"failed_polls=rs.failed_polls, "
+			"availability=rs.availability, "
+			"last_updated=rs.last_updated");
+	}
 
 	if ((result = db_query(&mysql, LOCAL, query)) != 0) {
 		num_rows = mysql_num_rows(result);
@@ -835,42 +891,42 @@ void poller_push_data_to_main() {
 						sqlp += sprintf(sqlp, ", (");
 					}
 
-					sqlp += sprintf(sqlp, "%s, ", row[0]); // id
+					sqlp += sprintf(sqlp, "%s, ", row[0]); // id mediumint
 
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[1]); // snmp_sysDescr
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[1]); // snmp_sysDescr varchar(300)
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[2]); // snmp_sysObjectID
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[2]); // snmp_sysObjectID varchar(128)
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[3]); // snmp_sysUpTimeInstance
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[3]); // snmp_sysUpTimeInstance bigint
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[4]); // snmp_sysContact
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[4]); // snmp_sysContact varchar(300)
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[5]); // snmp_sysName
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[5]); // snmp_sysName varchar(300)
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[6]); // snmp_sysLocation
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[6]); // snmp_sysLocation varchar(300)
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[7]); // status
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[7]); // status tinyint
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
 
-					sqlp += sprintf(sqlp, "%s, ", row[8]); // status_event_count
+					sqlp += sprintf(sqlp, "%s, ", row[8]); // status_event_count mediumint
 
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[9]);  // status_event_date
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[9]);  // status_fail_date timestamp
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[10]); // status_rec_date
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[10]); // status_rec_date timestamp
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[11]); // status_last_error
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[11]); // status_last_error varchar(255)
 					sqlp += sprintf(sqlp, "'%s', ", tmpstr);
 
-					sqlp += sprintf(sqlp, "%s, ", row[12]); // min_time
-					sqlp += sprintf(sqlp, "%s, ", row[13]); // max_time
-					sqlp += sprintf(sqlp, "%s, ", row[14]); // cur_time
-					sqlp += sprintf(sqlp, "%s, ", row[15]); // avg_time
-					sqlp += sprintf(sqlp, "%s, ", row[16]); // polling_time
-					sqlp += sprintf(sqlp, "%s, ", row[17]); // total_polls
-					sqlp += sprintf(sqlp, "%s, ", row[18]); // failed_polls
-					sqlp += sprintf(sqlp, "%s, ", row[19]); // availability
+					sqlp += sprintf(sqlp, "%s, ", row[12]); // min_time decimal(10,5)
+					sqlp += sprintf(sqlp, "%s, ", row[13]); // max_time decimal(10,5)
+					sqlp += sprintf(sqlp, "%s, ", row[14]); // cur_time decimal(10,5)
+					sqlp += sprintf(sqlp, "%s, ", row[15]); // avg_time decimal(10,5)
+					sqlp += sprintf(sqlp, "%s, ", row[16]); // polling_time double
+					sqlp += sprintf(sqlp, "%s, ", row[17]); // total_polls int
+					sqlp += sprintf(sqlp, "%s, ", row[18]); // failed_polls int
+					sqlp += sprintf(sqlp, "%s, ", row[19]); // availability decimal(8,5)
 
-					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[20]); // last_updated
+					db_escape(&mysql, tmpstr, sizeof(tmpstr), row[20]); // last_updated timestamp
 					sqlp += sprintf(sqlp, "'%s'", tmpstr);
 
 					sqlp += sprintf(sqlp, ")");
@@ -909,8 +965,13 @@ void poller_push_data_to_main() {
 
 	snprintf(prefix, BUFSIZE, "INSERT INTO poller_item (local_data_id, host_id, rrd_name, rrd_step, rrd_next_step) VALUES ");
 
-	snprintf(suffix, BUFSIZE, " ON DUPLICATE KEY UPDATE "
-		"rrd_next_step=VALUES(rrd_next_step);");
+	if (set.dbonupdate == 0) {
+		snprintf(suffix, BUFSIZE, " ON DUPLICATE KEY UPDATE "
+			"rrd_next_step=VALUES(rrd_next_step)");
+	} else {
+		snprintf(suffix, BUFSIZE, " AS rs ON DUPLICATE KEY UPDATE "
+			"rrd_next_step=rs.rrd_next_step");
+	}
 
 	if ((result = db_query(&mysql, LOCAL, query)) != 0) {
 		num_rows = mysql_num_rows(result);
@@ -1692,6 +1753,21 @@ char *reverse(char* str) {
 	return str;
 }
 
+/*! \fn strpos()
+ *  \brief looks for the position of needle in haystack
+ *
+ *  \return the position of -1 if not found
+ */
+int strpos(char *haystack, char *needle) {
+	char *p = strstr(haystack, needle);
+
+	if (p) {
+		return p - haystack;
+	}
+
+	return -1;
+}
+
 /*! \fn char_count()
  *  \brief counts occurrences of char in string.
  *
